Dictionary

Struct Dictionary 

#[repr(transparent)]
pub struct Dictionary(pub(crate) KVec<KeyValuePair>);
A vector of Neovim (String, Object) pairs.

Tuple Fields

0: KVec<KeyValuePair>

Implementations



impl Dictionary

pub fn as_slice(&self) -> &[KeyValuePair]

Returns a slice of all key-value pairs in the dictionary.

pub fn as_mut_slice(&mut self) -> &mut [KeyValuePair]

Returns a mutable slice of all key-value pairs in the dictionary.

pub fn get<Q>(&self, query: &Q) -> Option<&Object>
where Q: PartialEq<String> + ?Sized,

Returns a reference to the value corresponding to the key.

pub fn get_index<Q>(&self, query: &Q) -> Option<usize>
where Q: PartialEq<String> + ?Sized,

Returns the index of the key-value pair corresponding to the key.

pub fn get_mut<Q>(&mut self, query: &Q) -> Option<&mut Object>
where Q: PartialEq<String> + ?Sized,

Returns a mutable reference to the value corresponding to the key.

pub fn insert<K, V>(&mut self, key: K, value: V)
where K: Into<String>, V: Into<Object>,

Inserts a key-value pair into the dictionary.

pub fn is_empty(&self) -> bool

Returns true if the dictionary contains no elements.

pub fn iter(&self) -> DictIter<'_>

Returns an iterator over the (String, Object) pairs of the dictionary.

pub fn iter_mut(&mut self) -> DictIterMut<'_>

Returns a mutable iterator over the (String, Object) pairs of the dictionary.

pub fn len(&self) -> usize

Returns the number of elements in the dictionary.

pub fn keys(&self) -> impl Iterator<Item = &String>

Returns an iterator over the keys of the dictionary.

pub fn new() -> Dictionary

Creates a new, empty Dictionary.

pub fn non_owning(&self) -> NonOwning<'_, Dictionary>

Returns a non-owning version of this Array.

pub fn swap_remove(&mut self, index: usize) -> KeyValuePair

Removes a KeyValuePair from the Dictionary and returns it.

The removed pair is replaced by the last element of the dictionary.

Panics

Panics if index is out of bounds.